/* File: calc.h
   Author: Richard Eisenberg (eir@cis)
   Desc: defines the window class for a basic calculator
*/

#ifndef CALC_H_
#define CALC_H_

#include <QtGui>

class Calc : public QWidget
{
  Q_OBJECT
  // the line above is necessary to signal to Qt that this inherits from
  // QObject

 public:
  Calc();

 private slots:
  void number(int n);        // a number key was pressed
  void dot();                // the decimal point
  void opButton(QString op); // +, -, *, or /
  void equal();              // =
  void backspace();          // <-
  void clear();              // C

 private:
  // conditionally append a character to the display, if it makes sense
  void maybeAppend(const QString& str);

  // perform the queued-up operation
  void performLastOp();

  bool newNumber; // true when the next numerical input overwrites
  double lastNumber; // the last number input
  QString lastOp; // the last op, or ""

  QLineEdit* display; // the actual display on the calculator

  // These are constants. The "static" means that they do not belong
  // to a particular Calc instance, but are declared globally.
  // The QStrings cannot be given values here, because they are more
  // involved -- a QString needs memory to be allocated, so it must
  // be given its value in a .cpp file. The int, on the other hand,
  // can be textually replaced everywhere, so it does not need memory
  // in the running program.
  static const QString PLUS, MINUS, TIMES, DIVIDE;
  static const int NUM_OPS = 4;
};

#endif
